@@ -21,7 +21,7 @@ def get_service_max_capacity_from_service_arn(service_arn):
     tag_description_result = ecs_client.list_tags_for_resource(resourceArn=service_arn)
     tags = tag_description_result.get('tags')
     for i in range(len(tags)):
-        if tags[i].get("key") == "max_capacity":
+        if tags[i].get("key") == "MaxCapacity":
             return int(tags[i].get("value"))
 
 
